<?php
/*
 * @author Klaas Eikelboom  <klaas.eikelboom@civicoop.org>
 * @date 16-Dec-2022
 * @license  GPL-2.0-or-later
 */
namespace Drupal\cmrf_form_processor_display\Element;

use Drupal\Core\Render\Annotation\FormElement;
use Drupal\Core\Render\Element\RenderElement;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\Core\Render\Element\Textfield;

/**
 * Provides a lookup using CiviMRF
 *
 * @FormElement("cmrf_display")
 */
class CMRFDisplay extends RenderElement {

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    $class = get_class($this);
    return [
      '#pre_render' => [
        [$class, 'preRenderCMRFDisplay'],
      ],
    ];
  }

  /**
   * @param array $element
   *
   * @return array
   */
  public static function preRenderCMRFDisplay(array $element) {
    if (isset($element['#default_value'])) {
      switch ($element['#cmrf_display_mode']){
        case 'link' :
          $markup = t('<a target="_blank" href=":url">:text</a>.',[
            ':url' =>  $element['#default_value'],
            ':text' => $element['#cmrf_display_text']
          ]);
          break;
        case 'button' :
          $markup = t('<a class=":atts" target="_blank" href=":url">:text</a>.',[
            ':atts' =>  $element['#cmrf_display_atts'],
            ':url' =>  $element['#default_value'],
            ':text' => $element['#cmrf_display_text']
          ]);
          break;
        default:
          $markup =  $element['#default_value'];
          break;
      }
      $element['#markup'] = $markup;
    }
    return $element;
  }

}
